@@ -7,7 +7,7 @@ use Mojo::JSON;
 use Mojo::Util;
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 my $X_RE = qr{^x-};
 
 has route     => sub {undef};
@@ -69,15 +69,17 @@ sub _add_default_response {
   my ($self, $op_spec) = @_;
   my $name        = $self->{default_response_name};
   my $schema_data = $self->validator->schema->data;
+  # turn off with config { default_response_codes => [] }
+  return unless @{$self->{default_response_codes}};
 
   my $ref
     = $self->validator->version ge '3'
-    ? ($schema_data->{components}{responses}{$name} ||= $self->_default_schema)
+    ? ($schema_data->{components}{schemas}{$name} ||= $self->_default_schema)
     : ($schema_data->{definitions}{$name} ||= $self->_default_schema);
 
   my %schema
     = $self->validator->version ge '3'
-    ? ('$ref' => "#/components/responses/$name")
+    ? ('$ref' => "#/components/schemas/$name")
     : ('$ref' => "#/definitions/$name");
 
   tie %schema, 'JSON::Validator::Ref', $ref, $schema{'$ref'}, $schema{'$ref'};
